==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Arc/ArcCPA/ts/ArcCPA_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>ArcCPA</name>
    <message>
        <location filename="../ArcCPA.js" line="+66"/>
        <source>Center</source>
        <translation>Središče</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Point on arc or radius</source>
        <translation>Točka na loku ali radiu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Point on arc</source>
        <translation>Točka na loku</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Start angle</source>
        <translation>Začetni kot</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>End angle</source>
        <translation>Končni kot</translation>
    </message>
    <message>
        <location filename="../ArcCPA.ui" line="+17"/>
        <source>Direction:</source>
        <translation>Smer:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Counter Clockwise (positive)</source>
        <translation>Nasproti smeri urinega kazalca (Pozitivna)</translation>
    </message>
    <message>
        <location line="+13"/>
        <location line="+17"/>
        <source>Direction</source>
        <translation>Smer</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Clockwise (Negative)</source>
        <translation>V smeri urinega kazalca (Negativna)</translation>
    </message>
    <message>
        <location filename="../ArcCPAInit.js" line="+2"/>
        <source>&amp;Center, Point, Angles</source>
        <translation>&amp;Središče, Točka, Koti</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc from center, point on arc and angles</source>
        <translation>Nariši lok iz središča, točke na loku ter kotov</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Arc/ArcCPA/ts/ArcCPA_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>ArcCPA</name>
    <message>
        <location filename="../ArcCPA.js" line="+66"/>
        <source>Center</source>
        <translation>Središče</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Point on arc or radius</source>
        <translation>Točka na loku ali polmer</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Point on arc</source>
        <translation>Točka na loku</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Start angle</source>
        <translation>Začetni kot</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>End angle</source>
        <translation>Končni kot</translation>
    </message>
    <message>
        <location filename="../ArcCPA.ui" line="+17"/>
        <source>Direction:</source>
        <translation>Smer:</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Counter Clockwise (positive)</source>
        <translation>Nasproti smeri urinega kazalca (Pozitivna)</translation>
    </message>
    <message>
        <location line="+13"/>
        <location line="+17"/>
        <source>Direction</source>
        <translation>Smer</translation>
    </message>
    <message>
        <location line="-10"/>
        <source>Clockwise (Negative)</source>
        <translation>V smeri urinega kazalca (Negativna)</translation>
    </message>
    <message>
        <location filename="../ArcCPAInit.js" line="+2"/>
        <source>&amp;Center, Point, Angles</source>
        <translation>&amp;Središče, Točka, Koti</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw arc from center, point on arc and angles</source>
        <translation>Nariši lok iz središča, točke na loku ter kotov</translation>
    </message>
</context>
</TS>
